Index: trunk/Ohana/src/libfits/include/gfitsio.h
===================================================================
--- trunk/Ohana/src/libfits/include/gfitsio.h	(revision 41395)
+++ trunk/Ohana/src/libfits/include/gfitsio.h	(revision 41422)
@@ -18,6 +18,6 @@
 # endif /* NEWLINE */
 
-/* gfits_bintable_format returns 'byte' as the type associated with one-byte logical (non-char) values */
-typedef unsigned char byte;
+/* gfits_bintable_format returns 'gfbyte' as the type associated with one-byte logical (non-char) values */
+typedef unsigned char gfbyte;
 
 /********** FITS Constants *********/
